import { View, Text, Image } from '@tarojs/components'
import { useEffect, useMemo, useRef, useState } from 'react'
import dayjs from 'dayjs'
import { Button, Icon, Dialog } from "@antmjs/vantui";
import Taro from '@tarojs/taro';
import BarCode from '@/components/barcode'
import logo from '@/assets/water_logo.png'
import { useModel } from '../../store';

import './style.less'
import { getBarcode } from '../../services/user';

export default (props) => {
  const { person, user } = useModel('userData')
  const [barData, setBarData] = useState({})
  const [idCardVisible, setIdCardVisible] = useState(false)
  const [idCardBarVisible, setIdCardBarVisible] = useState(false)
  const today = useMemo(() => dayjs().format('YYYY-MM-DD'))
  const goUserInfo = () => {
    Taro.navigateTo({
      url: '/pages/setUserInfo/index'
    })
  }

  const handleShowEditor = () => {
    setIdCardVisible(false)
    goUserInfo()
  }

  useEffect(() => {
    if (person && person.personId) {
      getBarcode(person.personId).then((res) => {
        if (typeof res === 'string') {
          const resp = JSON.parse(res) || {}
          setBarData(resp)
        } else {
          setBarData(res || {})
        }
      })
    }

    if (user && user.userId) {
      if (!person || !person.idNo) {
        setIdCardVisible(true)
      } else {
        setIdCardVisible(false)
      }
    }
  }, [person, user])

  return (
    <View className='index-UserQRcode'>
      {/* <Text>Hello world!</Text> */}
      {/* <View className='index-UserQRcode-headerInfo' style={{ backgroundImage: `url(${userBck})` }}> */}
      <View className='index-UserQRcode-headerInfo' >
        <View className='index-UserQRcode-headerInfo-User'>
          <Image src={logo} />
          <View className='index-UserQRcode-headerInfo-User-NameInfo'>姓名：{person?.personName}</View>
          <View onClick={goUserInfo} className='index-UserQRcode-headerInfo-User-setNameInfo'><Icon name='edit' />修改信息</View>
        </View>
        <View className='index-UserQRcode-headerInfo-UserID'>科室：{person?.deptName}</View>
      </View>
      <View className='index-UserQRcode-cententQR'>
        <View className='index-UserQRcode-cententQR-Barcode'>
          <BarCode ratio={0.7} height={80} code={barData.barcode} />
        </View>
      </View>
      <View className='index-UserQRcode-footer'>
        <View>
          <Button block plain hairline type='info' size='large' onClick={() => setIdCardBarVisible(true)}>
            <View style={{ fontSize: '1.2em' }}>查看身份码</View>
          </Button>
          <View className='date-tip'>
          {today}
          </View>
        </View>
      </View>
      <Dialog title='提示' message='未添加个人信息' show={idCardVisible} onConfirm={handleShowEditor} />
      <Dialog show={idCardBarVisible} onConfirm={() => setIdCardBarVisible(false)}>
        <View className='pop-idcard-bar'>
          <BarCode ratio={0.7} height={80} code={person?.idNo} codeVisible />
        </View>
      </Dialog>
    </View>
  )
}




